FFormBuilder<T extends FForm> constructor

const FFormBuilder<T extends FForm>({
  1. required T form,
  2. required FFormWidgetBuilder<T> builder,
  3. Widget? child,
  4. Key? key,
})

A widget that builds and manages the state of a form.

FFormBuilder is used to create a form and handle its state management. It listens to the form's state changes and rebuilds its descendants accordingly.

Example

final form = MyForm();

FFormBuilder<MyForm>(
  form: form,
  builder: (context, form) {
    return Column(
      children: [
        // Build form fields using form
      ],
    );
  },
);

Implementation

const FFormBuilder({
  required this.form,
  required this.builder,
  this.child,
  super.key,
});