FFormException constructor

FFormException()

An abstract class representing an exception for form fields.

Provides a method to check if the exception indicates a valid state.

Example

class MyException extends FFormException {
  @override
  bool get isValid => false;
}

Implementation

FFormException();