FFormException class abstract
An abstract class representing an exception for form fields.
Provides a method to check if the exception indicates a valid state.
Constructors
- FFormException()
- An abstract class representing an exception for form fields.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited